<?php

namespace Drupal\views_vcards\Plugin\ViewsVcards\Property;

use Drupal\Core\Form\FormStateInterface;
use Drupal\views_vcards\VcardPropertyPluginBase;
use Drupal\views_vcards\VcardPropertyPluginInterface;

/**
 * Defines a vcard ADR property.
 *
 * @ViewsVcardsProperty(
 *   id = "adr",
 *   title = @Translation("Address"),
 *   property = "ADR",
 *   supportsHomeWorkType = true,
 * )
 */
class Adr extends VcardPropertyPluginBase implements VcardPropertyPluginInterface {

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    // Init the style plugin so that we retrieve the available fields.
    $this->view->initStyle();

    $form['address'] = [
      '#type' => 'select',
      '#title' => $this->t('Street address'),
      '#options' => $this->view->rowPlugin->displayHandler->getFieldLabels(),
      '#empty_option' => $this->t('- Select -'),
      '#default_value' => $this->getConfiguration('address'),
    ];
    $form['locality'] = [
      '#type' => 'select',
      '#title' => $this->t('Locality (e.g., city)'),
      '#options' => $this->view->rowPlugin->displayHandler->getFieldLabels(),
      '#empty_option' => $this->t('- Select -'),
      '#default_value' => $this->getConfiguration('locality'),
    ];
    $form['region'] = [
      '#type' => 'select',
      '#title' => $this->t('Region (e.g., state or province)'),
      '#options' => $this->view->rowPlugin->displayHandler->getFieldLabels(),
      '#empty_option' => $this->t('- Select -'),
      '#default_value' => $this->getConfiguration('region'),
    ];
    $form['postal_code'] = [
      '#type' => 'select',
      '#title' => $this->t('Postal code'),
      '#options' => $this->view->rowPlugin->displayHandler->getFieldLabels(),
      '#empty_option' => $this->t('- Select -'),
      '#default_value' => $this->getConfiguration('postal_code'),
    ];
    $form['country'] = [
      '#type' => 'select',
      '#title' => $this->t('Country'),
      '#options' => $this->view->rowPlugin->displayHandler->getFieldLabels(),
      '#empty_option' => $this->t('- Select -'),
      '#default_value' => $this->getConfiguration('country'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function prepareOutputString($index, $params = [], $group = '') {
    $property = $this->getPluginDefinition()['property'];

    // PO box and extended address should be empty.
    $po_box = '';
    $ext_address = '';
    $address = $this->getFieldValue($index, $this->getConfiguration('address'));
    $locality = $this->getFieldValue($index, $this->getConfiguration('locality'));
    $region = $this->getFieldValue($index, $this->getConfiguration('region'));
    $postal_code = $this->getFieldValue($index, $this->getConfiguration('postal_code'));
    $country = $this->getFieldValue($index, $this->getConfiguration('country'));

    return $property . ':' . $po_box . ";" . $ext_address . ";" . $address . ";" . $locality . ";" . $region . ";" . $postal_code . ";" . $country;
  }

}
