<?php

namespace Drupal\views_vcards\Plugin\ViewsVcards\Property;

use Drupal\Core\Form\FormStateInterface;
use Drupal\views_vcards\VcardPropertyPluginBase;
use Drupal\views_vcards\VcardPropertyPluginInterface;

/**
 * Defines a vcard N property.
 *
 * @ViewsVcardsProperty(
 *   id = "n",
 *   title = @Translation("Name"),
 *   property = "N",
 * )
 */
class Name extends VcardPropertyPluginBase implements VcardPropertyPluginInterface {

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    // Init the style plugin so that we retrieve the available fields.
    $this->view->initStyle();

    $form['family_names'] = [
      '#type' => 'select',
      '#title' => $this->t('Family Name(s)'),
      '#options' => $this->view->rowPlugin->displayHandler->getFieldLabels(),
      '#empty_option' => $this->t('- Select -'),
      '#default_value' => $this->getConfiguration('family_names'),
    ];
    $form['given_names'] = [
      '#type' => 'select',
      '#title' => $this->t('Given Name(s)'),
      '#options' => $this->view->rowPlugin->displayHandler->getFieldLabels(),
      '#empty_option' => $this->t('- Select -'),
      '#default_value' => $this->getConfiguration('given_names'),
    ];
    $form['additional_names'] = [
      '#type' => 'select',
      '#title' => $this->t('Additional Name(s)'),
      '#options' => $this->view->rowPlugin->displayHandler->getFieldLabels(),
      '#empty_option' => $this->t('- Select -'),
      '#default_value' => $this->getConfiguration('additional_names'),
    ];
    $form['honorific_prefixes'] = [
      '#type' => 'select',
      '#title' => $this->t('Honorific Prefix(es)'),
      '#options' => $this->view->rowPlugin->displayHandler->getFieldLabels(),
      '#empty_option' => $this->t('- Select -'),
      '#default_value' => $this->getConfiguration('honorific_prefixes'),
    ];
    $form['honorific_suffixes'] = [
      '#type' => 'select',
      '#title' => $this->t('Honorific Suffix(es)'),
      '#options' => $this->view->rowPlugin->displayHandler->getFieldLabels(),
      '#empty_option' => $this->t('- Select -'),
      '#default_value' => $this->getConfiguration('honorific_suffixes'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function prepareOutputString($index, $params = [], $group = '') {
    $property = $this->getPluginDefinition()['property'];

    $family_names = $this->getFieldValue($index, $this->getConfiguration('family_names'));
    $given_names = $this->getFieldValue($index, $this->getConfiguration('given_names'));
    $additional_names = $this->getFieldValue($index, $this->getConfiguration('additional_names'));
    $honorific_prefixes = $this->getFieldValue($index, $this->getConfiguration('honorific_prefixes'));
    $honorific_suffixes = $this->getFieldValue($index, $this->getConfiguration('honorific_suffixes'));

    return $property . ':' . $family_names . ";" . $given_names . ";" . $additional_names . ";" . $honorific_prefixes . ";" . $honorific_suffixes;
  }

}
