<?php

namespace Drupal\views_vcards\Plugin\ViewsVcards\Property;

use Drupal\file\Entity\File;
use Drupal\image\Entity\ImageStyle;
use Drupal\views_vcards\VcardPropertyPluginBase;
use Drupal\views_vcards\VcardPropertyPluginInterface;

/**
 * Defines a vcard PHOTO property.
 *
 * @ViewsVcardsProperty(
 *   id = "photo",
 *   title = @Translation("Photo"),
 *   property = "PHOTO",
 * )
 */
class Photo extends VcardPropertyPluginBase implements VcardPropertyPluginInterface {

  /**
   * {@inheritdoc}
   */
  public function prepareOutputString($index, $params = [], $group = '') {
    $property = $this->getPluginDefinition()['property'];
    $fid = $this->getFieldValue($index, $this->getConfiguration('views_field'));
    $output_string = '';

    if (!empty($fid) && $file = File::load($fid)) {
      // Use the default uri, unless there is an image style.
      $image_uri = $original_image = $file->getFileUri();
      // Obtain desired image style.
      $image_style = $this->view->field[$this->getConfiguration('views_field')]->options['settings']['image_style'];
      if ($image_style) {
        $style = ImageStyle::load($image_style);
        $styled_image_uri = $style->buildUri($original_image);
        if ($style->createDerivative($original_image, $styled_image_uri)) {
          // Successfully created styled image.
          $image_uri = $styled_image_uri;
        }
      }

      $imgbinary = file_get_contents($image_uri);
      $photo = base64_encode($imgbinary);
      $mimetype = $file->getMimeType();

      $types = $this->getConfiguration('type');

      if ($types) {
        $params[] = 'TYPE=' . implode(',', $types);
      }

      $params[] = 'ENCODING=BASE64';
      $params[] = 'MEDIATYPE=' . $mimetype;

      // Build the vCard content line according the ABNF Format Definition.
      $output_string = $property . ';' . implode(';', $params) . ':' . $photo;
    }

    return $output_string;
  }

  /**
   * {@inheritdoc}
   */
  public function render($index, $params = [], $group = '') {
    $output_string = $this->prepareOutputString($index, $params, $group);
    // Finally return a line wrapped at 63 characters.
    $output = substr($output_string, 0, 64) . "\r\n ";
    $output .= chunk_split(substr($output_string, 64), 63, "\r\n ");
    // Remove last newline.
    return rtrim($output);
  }

}
