<?php

namespace Drupal\views_vcards;

use Drupal\Component\Plugin\ConfigurableInterface;
use Drupal\Component\Plugin\DependentPluginInterface;
use Drupal\Core\Plugin\PluginFormInterface;
use Drupal\views\ViewExecutable;

/**
 * Defines the interface to be used for all VcardPropertyPlugins.
 */
interface VcardPropertyPluginInterface extends ConfigurableInterface, DependentPluginInterface, PluginFormInterface {

  /**
   * Set the given view for the plugin.
   *
   * @param \Drupal\views\ViewExecutable $view
   *   The view to set.
   */
  public function setView(ViewExecutable $view);

  /**
   * Returns the property's content line, formatted for output in the vCard.
   *
   * @param int $index
   *   The index (row number) of the field.
   * @param string[] $params
   *   Optional array of parameters to add to this property. (e.g., 'TYPE=foo')
   * @param string $group
   *   Optional group.
   *
   * @return string|null
   *   The property's content line. NULL if the property is empty.
   */
  public function render($index, $params = [], $group = '');

}
